==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Scale/ts/Scale_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Scale</name>
    <message>
        <location filename="../Scale.js" line="+71"/>
        <source>Focus point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Punkt ostrości</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Reference point</source>
        <translatorcomment>--google--
Wskaż punkt odniesienia
Kopiuje obiekty do schowka z punktem odniesienia
Wycina obiekty z punktem odniesienia</translatorcomment>
        <translation type="unfinished">Punkt odniesienia</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Target point</source>
        <translatorcomment>--google--
Wskaż punkt docelowy</translatorcomment>
        <translation type="unfinished">Punkt docelowy</translation>
    </message>
    <message>
        <location filename="../ScaleInit.js" line="+2"/>
        <source>&amp;Scale</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Skaluj</translatorcomment>
        <translation type="unfinished">&amp;Skaluj</translation>
    </message>
</context>
<context>
    <name>ScaleOptions</name>
    <message>
        <location filename="../ScaleDialog.ui" line="+14"/>
        <source>Scale Options</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Opcje skalowania</translatorcomment>
        <translation type="unfinished">Opcje skalowania</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Liczba kopii
Wprowadź liczbę kopii</translatorcomment>
        <translation type="unfinished">Liczba kopii</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Usuń oryginał</translatorcomment>
        <translation type="unfinished">&amp;Usuń oryginał</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Zachowaj oryginał</translatorcomment>
        <translation type="unfinished">&amp;Zachowaj oryginał</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Kopie &amp;wielokrotne
Kopie &amp;wielokrotne:</translatorcomment>
        <translation type="unfinished">Kopie &amp;wielokrotne</translation>
    </message>
    <message>
        <location line="+112"/>
        <source>Factor &amp;x:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Mnożnik &amp;X:</translatorcomment>
        <translation type="unfinished">Mnożnik &amp;X:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Proportional</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Factor &amp;y:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Mnożnik &amp;Y:</translatorcomment>
        <translation type="unfinished">Mnożnik &amp;Y:</translation>
    </message>
    <message>
        <location line="+66"/>
        <source>Use current layer and &amp;attributes</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Użyj bieżącej warstwy i atrybuty</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Scale/ts/Scale_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Scale</name>
    <message>
        <location filename="../Scale.js" line="+71"/>
        <source>Focus point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Punkt skupienia</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Reference point</source>
        <translatorcomment>--google--
Wskaż punkt odniesienia
Kopiuje obiekty do schowka z punktem odniesienia
Wycina obiekty z punktem odniesienia</translatorcomment>
        <translation>Punkt odniesienia</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Target point</source>
        <translatorcomment>--google--
Wskaż punkt docelowy</translatorcomment>
        <translation>Punkt docelowy</translation>
    </message>
    <message>
        <location filename="../ScaleInit.js" line="+2"/>
        <source>&amp;Scale</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Skaluj</translatorcomment>
        <translation>Prze&amp;skaluj</translation>
    </message>
</context>
<context>
    <name>ScaleOptions</name>
    <message>
        <location filename="../ScaleDialog.ui" line="+14"/>
        <source>Scale Options</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Opcje skalowania</translatorcomment>
        <translation>Opcje skalowania</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Liczba kopii
Wprowadź liczbę kopii</translatorcomment>
        <translation>Liczba kopii</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Usuń oryginał</translatorcomment>
        <translation>&amp;Usunięcie oryginału</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Zachowaj oryginał</translatorcomment>
        <translation>&amp;Zachowanie oryginału</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Kopie &amp;wielokrotne
Kopie &amp;wielokrotne:</translatorcomment>
        <translation>&amp;Wielokrotne skopiowanie</translation>
    </message>
    <message>
        <location line="+112"/>
        <source>Factor &amp;x:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Mnożnik &amp;X:</translatorcomment>
        <translation>Współczynnik skali wzdłuż osi &amp;X:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Proportional</source>
        <translation>Proporcjonalnie</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Factor &amp;y:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Mnożnik &amp;Y:</translatorcomment>
        <translation>Współczynnik skali wzdłuż osi &amp;Y:</translation>
    </message>
    <message>
        <location line="+66"/>
        <source>Use current layer and &amp;attributes</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Użycie aktualnej warstwy i &amp;atrybutów</translation>
    </message>
</context>
</TS>
